@@ -12,7 +12,8 @@
 #include <QString>
 #include <QVector>
 
-namespace Konsole {
+namespace Konsole
+{
 /**
  * Takes a snapshot of the state of a process and provides access to
  * information such as the process name, parent process,
@@ -152,7 +153,7 @@ public:
         /** The nature of the error is unknown. */
         UnknownError,
         /** Konsole does not have permission to obtain the process information. */
-        PermissionsError
+        PermissionsError,
     };
 
     /**
@@ -167,7 +168,7 @@ public:
         ARGUMENTS = 8,
         NAME = 16,
         CURRENT_DIR = 32,
-        UID = 64
+        UID = 64,
     };
     Q_DECLARE_FLAGS(Fields, Field)
 
@@ -251,7 +252,6 @@ protected:
     bool userNameRequired() const;
 
 private:
-
     Fields _fields;
 
     int _pid;
@@ -270,11 +270,11 @@ private:
 
     QVector<QString> _arguments;
 
-    static QSet<QString> commonDirNames();
-    static QSet<QString> _commonDirNames;
+    static QStringList commonDirNames();
+    static QStringList _commonDirNames;
 };
 Q_DECLARE_OPERATORS_FOR_FLAGS(ProcessInfo::Fields)
 
 }
 
-#endif //PROCESSINFO_H
+#endif // PROCESSINFO_H
