@@ -20,33 +20,34 @@
 class QTimer;
 class QKeyEvent;
 
-#define MODE_AppCuKeys       (MODES_SCREEN+0)   // Application cursor keys (DECCKM)
-#define MODE_AppKeyPad       (MODES_SCREEN+1)   //
-#define MODE_Mouse1000       (MODES_SCREEN+2)   // Send mouse X,Y position on press and release
-#define MODE_Mouse1001       (MODES_SCREEN+3)   // Use Hilight mouse tracking
-#define MODE_Mouse1002       (MODES_SCREEN+4)   // Use cell motion mouse tracking
-#define MODE_Mouse1003       (MODES_SCREEN+5)   // Use all motion mouse tracking
-#define MODE_Mouse1005       (MODES_SCREEN+6)   // Xterm-style extended coordinates
-#define MODE_Mouse1006       (MODES_SCREEN+7)   // 2nd Xterm-style extended coordinates
-#define MODE_Mouse1007       (MODES_SCREEN+8)   // XTerm Alternate Scroll mode; also check AlternateScrolling profile property
-#define MODE_Mouse1015       (MODES_SCREEN+9)   // Urxvt-style extended coordinates
-#define MODE_Ansi            (MODES_SCREEN+10)   // Use US Ascii for character sets G0-G3 (DECANM)
-#define MODE_132Columns      (MODES_SCREEN+11)  // 80 <-> 132 column mode switch (DECCOLM)
-#define MODE_Allow132Columns (MODES_SCREEN+12)  // Allow DECCOLM mode
-#define MODE_BracketedPaste  (MODES_SCREEN+13)  // Xterm-style bracketed paste mode
-#define MODE_total           (MODES_SCREEN+14)
+#define MODE_AppCuKeys (MODES_SCREEN + 0) // Application cursor keys (DECCKM)
+#define MODE_AppKeyPad (MODES_SCREEN + 1) //
+#define MODE_Mouse1000 (MODES_SCREEN + 2) // Send mouse X,Y position on press and release
+#define MODE_Mouse1001 (MODES_SCREEN + 3) // Use Hilight mouse tracking
+#define MODE_Mouse1002 (MODES_SCREEN + 4) // Use cell motion mouse tracking
+#define MODE_Mouse1003 (MODES_SCREEN + 5) // Use all motion mouse tracking
+#define MODE_Mouse1005 (MODES_SCREEN + 6) // Xterm-style extended coordinates
+#define MODE_Mouse1006 (MODES_SCREEN + 7) // 2nd Xterm-style extended coordinates
+#define MODE_Mouse1007 (MODES_SCREEN + 8) // XTerm Alternate Scroll mode; also check AlternateScrolling profile property
+#define MODE_Mouse1015 (MODES_SCREEN + 9) // Urxvt-style extended coordinates
+#define MODE_Ansi (MODES_SCREEN + 10) // Use US Ascii for character sets G0-G3 (DECANM)
+#define MODE_132Columns (MODES_SCREEN + 11) // 80 <-> 132 column mode switch (DECCOLM)
+#define MODE_Allow132Columns (MODES_SCREEN + 12) // Allow DECCOLM mode
+#define MODE_BracketedPaste (MODES_SCREEN + 13) // Xterm-style bracketed paste mode
+#define MODE_total (MODES_SCREEN + 14)
 
-namespace Konsole {
+namespace Konsole
+{
 extern unsigned short vt100_graphics[32];
 
 struct CharCodes {
     // coding info
     char charset[4]; //
-    int cu_cs;       // actual charset.
-    bool graphic;    // Some VT100 tricks
-    bool pound;      // Some VT100 tricks
+    int cu_cs; // actual charset.
+    bool graphic; // Some VT100 tricks
+    bool pound; // Some VT100 tricks
     bool sa_graphic; // saved graphic
-    bool sa_pound;   // saved pound
+    bool sa_pound; // saved pound
 };
 
 /**
@@ -59,7 +60,7 @@ struct CharCodes {
  * sequences.
  *
  */
-class Vt102Emulation : public Emulation
+class KONSOLEPRIVATE_EXPORT Vt102Emulation : public Emulation
 {
     Q_OBJECT
 
@@ -103,7 +104,7 @@ private:
     void resetCharset(int scrno);
 
     void setMargins(int top, int bottom);
-    //set margins for all screens back to their defaults
+    // set margins for all screens back to their defaults
     void setDefaultMargins();
 
     // returns true if 'mode' is set or false otherwise
@@ -119,7 +120,7 @@ private:
     void resetTokenizer();
 #define MAX_TOKEN_LENGTH 256 // Max length of tokens (e.g. window title)
     void addToCurrentToken(uint cc);
-    uint tokenBuffer[MAX_TOKEN_LENGTH]; //FIXME: overflow?
+    uint tokenBuffer[MAX_TOKEN_LENGTH]; // FIXME: overflow?
     int tokenBufferPos;
 #define MAXARGS 15
     void addDigit(int dig);
