@@ -9,7 +9,8 @@
 
 #include "konsoleprivate_export.h"
 
-namespace Konsole {
+namespace Konsole
+{
 class KONSOLEPRIVATE_EXPORT WindowSystemInfo
 {
 public:
