@@ -10,14 +10,14 @@
 #include "qtest.h"
 
 // Konsole
-#include "../session/Session.h"
 #include "../Emulation.h"
-#include "../history/HistoryTypeNone.h"
-#include "../history/HistoryTypeFile.h"
-#include "../history/compact/CompactHistoryType.h"
-#include "../history/HistoryScrollNone.h"
 #include "../history/HistoryScrollFile.h"
+#include "../history/HistoryScrollNone.h"
+#include "../history/HistoryTypeFile.h"
+#include "../history/HistoryTypeNone.h"
 #include "../history/compact/CompactHistoryScroll.h"
+#include "../history/compact/CompactHistoryType.h"
+#include "../session/Session.h"
 
 using namespace Konsole;
 
@@ -93,8 +93,6 @@ void HistoryTest::testHistoryScroll()
     historyScroll = new HistoryScrollNone();
     QVERIFY(!historyScroll->hasScroll());
     QCOMPARE(historyScroll->getLines(), 0);
-    QCOMPARE(historyScroll->getLineLen(0), 0);
-    QCOMPARE(historyScroll->getLineLen(10), 0);
 
     const HistoryType &historyTypeNone = historyScroll->getType();
     QCOMPARE(historyTypeNone.isEnabled(), false);
@@ -107,8 +105,6 @@ void HistoryTest::testHistoryScroll()
     historyScroll = new HistoryScrollFile();
     QVERIFY(historyScroll->hasScroll());
     QCOMPARE(historyScroll->getLines(), 0);
-    QCOMPARE(historyScroll->getLineLen(0), 0);
-    QCOMPARE(historyScroll->getLineLen(10), 0);
 
     const HistoryType &historyTypeFile = historyScroll->getType();
     QCOMPARE(historyTypeFile.isEnabled(), true);
@@ -121,8 +117,6 @@ void HistoryTest::testHistoryScroll()
     historyScroll = new CompactHistoryScroll(42);
     QVERIFY(historyScroll->hasScroll());
     QCOMPARE(historyScroll->getLines(), 0);
-    QCOMPARE(historyScroll->getLineLen(0), 0);
-    QCOMPARE(historyScroll->getLineLen(10), 0);
 
     const HistoryType &compactHistoryType = historyScroll->getType();
     QCOMPARE(compactHistoryType.isEnabled(), true);
@@ -196,7 +190,7 @@ void HistoryTest::testHistoryReflow()
 
 void HistoryTest::testHistoryTypeChange()
 {
-    HistoryScroll *historyScroll = nullptr;
+    std::unique_ptr<HistoryScroll> historyScroll(nullptr);
 
     const char testString[] = "abcdefghijklmnopqrstuvwxyz1234567890";
     const int testStringSize = sizeof(testString) / sizeof(char) - 1;
@@ -208,11 +202,11 @@ void HistoryTest::testHistoryTypeChange()
 
     // None
     auto historyTypeNone = new HistoryTypeNone();
-    historyScroll = historyTypeNone->scroll(historyScroll);
+    historyTypeNone->scroll(historyScroll);
 
     // None to File
     auto historyTypeFile = new HistoryTypeFile();
-    historyScroll = historyTypeFile->scroll(historyScroll);
+    historyTypeFile->scroll(historyScroll);
 
     historyScroll->addCells(testImage, testStringSize);
     historyScroll->addLine(false);
@@ -223,23 +217,22 @@ void HistoryTest::testHistoryTypeChange()
 
     // File to Compact
     auto compactHistoryType = new CompactHistoryType(10);
-    historyScroll = compactHistoryType->scroll(historyScroll);
+    compactHistoryType->scroll(historyScroll);
 
     QCOMPARE(historyScroll->getLines(), 10);
     historyScroll->getCells(0, 0, 1, &testChar);
     QCOMPARE(testChar, testImage[testStringSize - 10]);
 
     // Compact to File
-    historyScroll = historyTypeFile->scroll(historyScroll);
+    historyTypeFile->scroll(historyScroll);
     QCOMPARE(historyScroll->getLines(), 10);
     historyScroll->getCells(0, 0, 1, &testChar);
     QCOMPARE(testChar, testImage[testStringSize - 10]);
 
     // File to None
-    historyScroll = historyTypeNone->scroll(historyScroll);
+    historyTypeNone->scroll(historyScroll);
     QCOMPARE(historyScroll->getLines(), 0);
 
-    delete historyScroll;
     delete historyTypeFile;
     delete historyTypeNone;
     delete compactHistoryType;
