@@ -11,20 +11,20 @@
 
 namespace Konsole
 {
-
 class ProfileTest : public QObject
 {
     Q_OBJECT
 
 private Q_SLOTS:
+    void initTestCase();
     void testProfile();
     void testClone();
     void testProfileGroup();
     void testProfileFileNames();
+    void testProfileNameSorting();
     void testFallbackProfile();
 };
 
 }
 
 #endif // PROFILETEST_H
-
