@@ -15,30 +15,33 @@
 // Qt
 #include <QVector>
 
-namespace Konsole {
+namespace Konsole
+{
 typedef unsigned char LineProperty;
 
 typedef quint16 RenditionFlags;
 
-const int LINE_DEFAULT             = 0;
-const int LINE_WRAPPED             = (1 << 0);
-const int LINE_DOUBLEWIDTH         = (1 << 1);
-const int LINE_DOUBLEHEIGHT_TOP    = (1 << 2);
-const int LINE_DOUBLEHEIGHT_BOTTOM = (1 << 3);
+/* clang-format off */
+const int LINE_DEFAULT              = 0;
+const int LINE_WRAPPED              = (1 << 0);
+const int LINE_DOUBLEWIDTH          = (1 << 1);
+const int LINE_DOUBLEHEIGHT_TOP     = (1 << 2);
+const int LINE_DOUBLEHEIGHT_BOTTOM  = (1 << 3);
 
-const RenditionFlags DEFAULT_RENDITION = 0;
-const RenditionFlags RE_BOLD           = (1 << 0);
-const RenditionFlags RE_BLINK          = (1 << 1);
-const RenditionFlags RE_UNDERLINE      = (1 << 2);
-const RenditionFlags RE_REVERSE        = (1 << 3); // Screen only
-const RenditionFlags RE_ITALIC         = (1 << 4);
-const RenditionFlags RE_CURSOR         = (1 << 5);
-const RenditionFlags RE_EXTENDED_CHAR  = (1 << 6);
-const RenditionFlags RE_FAINT          = (1 << 7);
-const RenditionFlags RE_STRIKEOUT      = (1 << 8);
-const RenditionFlags RE_CONCEAL        = (1 << 9);
-const RenditionFlags RE_OVERLINE       = (1 << 10);
+const RenditionFlags DEFAULT_RENDITION  = 0;
+const RenditionFlags RE_BOLD            = (1 << 0);
+const RenditionFlags RE_BLINK           = (1 << 1);
+const RenditionFlags RE_UNDERLINE       = (1 << 2);
+const RenditionFlags RE_REVERSE         = (1 << 3); // Screen only
+const RenditionFlags RE_ITALIC          = (1 << 4);
+const RenditionFlags RE_CURSOR          = (1 << 5);
+const RenditionFlags RE_EXTENDED_CHAR   = (1 << 6);
+const RenditionFlags RE_FAINT           = (1 << 7);
+const RenditionFlags RE_STRIKEOUT       = (1 << 8);
+const RenditionFlags RE_CONCEAL         = (1 << 9);
+const RenditionFlags RE_OVERLINE        = (1 << 10);
 const RenditionFlags RE_BLEND_SELECTION_COLORS = (1 << 11);
+/* clang-format on */
 
 /**
  * A single character in the terminal which consists of a unicode character
@@ -60,15 +63,17 @@ public:
      *              simply as place holder.
      */
     explicit inline Character(uint _c = ' ',
-                              CharacterColor  _f = CharacterColor(COLOR_SPACE_DEFAULT, DEFAULT_FORE_COLOR),
-                              CharacterColor  _b = CharacterColor(COLOR_SPACE_DEFAULT, DEFAULT_BACK_COLOR),
-                              RenditionFlags  _r = DEFAULT_RENDITION,
+                              CharacterColor _f = CharacterColor(COLOR_SPACE_DEFAULT, DEFAULT_FORE_COLOR),
+                              CharacterColor _b = CharacterColor(COLOR_SPACE_DEFAULT, DEFAULT_BACK_COLOR),
+                              RenditionFlags _r = DEFAULT_RENDITION,
                               bool _real = true)
         : character(_c)
         , rendition(_r)
         , foregroundColor(_f)
         , backgroundColor(_b)
-        , isRealCharacter(_real) { }
+        , isRealCharacter(_real)
+    {
+    }
 
     /** The unicode character value for this character.
      *
@@ -107,13 +112,13 @@ public:
      * Compares two characters and returns true if they have the same unicode character value,
      * rendition and colors.
      */
-    friend bool operator ==(const Character &a, const Character &b);
+    friend bool operator==(const Character &a, const Character &b);
 
     /**
      * Compares two characters and returns true if they have different unicode character values,
      * renditions or colors.
      */
-    friend bool operator !=(const Character &a, const Character &b);
+    friend bool operator!=(const Character &a, const Character &b);
 
     inline bool isSpace() const
     {
@@ -124,15 +129,18 @@ public:
         }
     }
 
-    inline int width() const {
+    inline int width() const
+    {
         return width(character);
     }
 
-    static int width(uint ucs4) {
+    static int width(uint ucs4)
+    {
         return characterWidth(ucs4);
     }
 
-    static int stringWidth(const uint *ucs4Str, int len) {
+    static int stringWidth(const uint *ucs4Str, int len)
+    {
         int w = 0;
         for (int i = 0; i < len; ++i) {
             w += width(ucs4Str[i]);
@@ -140,27 +148,26 @@ public:
         return w;
     }
 
-    inline static int stringWidth(const QString &str) {
+    inline static int stringWidth(const QString &str)
+    {
         QVector<uint> ucs4Str = str.toUcs4();
         return stringWidth(ucs4Str.constData(), ucs4Str.length());
     }
 };
 
-inline bool operator ==(const Character &a, const Character &b)
+inline bool operator==(const Character &a, const Character &b)
 {
     return a.character == b.character && a.equalsFormat(b);
 }
 
-inline bool operator !=(const Character &a, const Character &b)
+inline bool operator!=(const Character &a, const Character &b)
 {
     return !operator==(a, b);
 }
 
 inline bool Character::equalsFormat(const Character &other) const
 {
-    return backgroundColor == other.backgroundColor
-           && foregroundColor == other.foregroundColor
-           && rendition == other.rendition;
+    return backgroundColor == other.backgroundColor && foregroundColor == other.foregroundColor && rendition == other.rendition;
 }
 }
 Q_DECLARE_TYPEINFO(Konsole::Character, Q_MOVABLE_TYPE);
