@@ -10,14 +10,12 @@ using namespace Konsole;
 
 bool CharacterFormat::equalsFormat(const CharacterFormat &other) const
 {
-    return (other.rendition & ~RE_EXTENDED_CHAR) == (rendition & ~RE_EXTENDED_CHAR)
-        && other.fgColor == fgColor && other.bgColor == bgColor;
+    return (other.rendition & ~RE_EXTENDED_CHAR) == (rendition & ~RE_EXTENDED_CHAR) && other.fgColor == fgColor && other.bgColor == bgColor;
 }
 
 bool CharacterFormat::equalsFormat(const Character &c) const
 {
-    return (c.rendition & ~RE_EXTENDED_CHAR) == (rendition & ~RE_EXTENDED_CHAR)
-        && c.foregroundColor == fgColor && c.backgroundColor == bgColor;
+    return (c.rendition & ~RE_EXTENDED_CHAR) == (rendition & ~RE_EXTENDED_CHAR) && c.foregroundColor == fgColor && c.backgroundColor == bgColor;
 }
 
 void CharacterFormat::setFormat(const Character &c)
