@@ -8,16 +8,16 @@
 
 // Own
 #include "ColorScheme.h"
-#include "hsluv.h"
 #include "RandomizationRange.h"
+#include "hsluv.h"
 
 // Qt
 #include <QPainter>
 
 // KDE
 #include <KConfig>
-#include <KLocalizedString>
 #include <KConfigGroup>
+#include <KLocalizedString>
 
 // STL
 #include <random>
@@ -25,18 +25,19 @@
 // Konsole
 #include "colorschemedebug.h"
 
-namespace {
+namespace
+{
 const int FGCOLOR_INDEX = 0;
 const int BGCOLOR_INDEX = 1;
 
-const char RandomHueRangeKey[]           = "RandomHueRange";
-const char RandomSaturationRangeKey[]    = "RandomSaturationRange";
-const char RandomLightnessRangeKey[]     = "RandomLightnessRange";
+const char RandomHueRangeKey[] = "RandomHueRange";
+const char RandomSaturationRangeKey[] = "RandomSaturationRange";
+const char RandomLightnessRangeKey[] = "RandomLightnessRange";
 const char EnableColorRandomizationKey[] = "ColorRandomization";
 
-const double MaxHue        = 360.0;
+const double MaxHue = 360.0;
 const double MaxSaturation = 100.0;
-const double MaxLightness  = 100.0;
+const double MaxLightness = 100.0;
 }
 
 using namespace Konsole;
@@ -77,10 +78,10 @@ const QColor ColorScheme::defaultTable[TABLE_COLORS] = {
     QColor(0x00, 0x00, 0x65),
     QColor(0x65, 0x00, 0x65),
     QColor(0x00, 0x65, 0x65),
-    QColor(0x65, 0x65, 0x65)
+    QColor(0x65, 0x65, 0x65),
 };
 
-const char * const ColorScheme::colorNames[TABLE_COLORS] = {
+const char *const ColorScheme::colorNames[TABLE_COLORS] = {
     "Foreground",
     "Background",
     "Color0",
@@ -110,9 +111,9 @@ const char * const ColorScheme::colorNames[TABLE_COLORS] = {
     "Color4Faint",
     "Color5Faint",
     "Color6Faint",
-    "Color7Faint"
+    "Color7Faint",
 };
-const char * const ColorScheme::translatedColorNames[TABLE_COLORS] = {
+const char *const ColorScheme::translatedColorNames[TABLE_COLORS] = {
     I18N_NOOP2("@item:intable palette", "Foreground"),
     I18N_NOOP2("@item:intable palette", "Background"),
     I18N_NOOP2("@item:intable palette", "Color 1"),
@@ -142,7 +143,7 @@ const char * const ColorScheme::translatedColorNames[TABLE_COLORS] = {
     I18N_NOOP2("@item:intable palette", "Color 5 (Faint)"),
     I18N_NOOP2("@item:intable palette", "Color 6 (Faint)"),
     I18N_NOOP2("@item:intable palette", "Color 7 (Faint)"),
-    I18N_NOOP2("@item:intable palette", "Color 8 (Faint)")
+    I18N_NOOP2("@item:intable palette", "Color 8 (Faint)"),
 };
 
 QString ColorScheme::colorNameForIndex(int index)
@@ -159,28 +160,28 @@ QString ColorScheme::translatedColorNameForIndex(int index)
     return i18nc("@item:intable palette", translatedColorNames[index]);
 }
 
-ColorScheme::ColorScheme() :
-    _description(QString()),
-    _name(QString()),
-    _table(nullptr),
-    _randomTable(nullptr),
-    _opacity(1.0),
-    _blur(false),
-    _colorRandomization(false),
-    _wallpaper(nullptr)
+ColorScheme::ColorScheme()
+    : _description(QString())
+    , _name(QString())
+    , _table(nullptr)
+    , _randomTable(nullptr)
+    , _opacity(1.0)
+    , _blur(false)
+    , _colorRandomization(false)
+    , _wallpaper(nullptr)
 {
     setWallpaper(QString());
 }
 
-ColorScheme::ColorScheme(const ColorScheme &other) :
-    _description(QString()),
-    _name(QString()),
-    _table(nullptr),
-    _randomTable(nullptr),
-    _opacity(other._opacity),
-    _blur(other._blur),
-    _colorRandomization(other._colorRandomization),
-    _wallpaper(other._wallpaper)
+ColorScheme::ColorScheme(const ColorScheme &other)
+    : _description(QString())
+    , _name(QString())
+    , _table(nullptr)
+    , _randomTable(nullptr)
+    , _opacity(other._opacity)
+    , _blur(other._blur)
+    , _colorRandomization(other._colorRandomization)
+    , _wallpaper(other._wallpaper)
 {
     setName(other.name());
     setDescription(other.description());
@@ -239,7 +240,7 @@ void ColorScheme::setColorTableEntry(int index, const QColor &entry)
         _table[index] = entry;
     } else {
         _table[index] = defaultTable[index];
-        qCDebug(ColorSchemeDebug)<<"ColorScheme"<<name()<<"has an invalid color index"<<index<<", using default table color";
+        qCDebug(ColorSchemeDebug) << "ColorScheme" << name() << "has an invalid color index" << index << ", using default table color";
     }
 }
 
@@ -249,16 +250,14 @@ QColor ColorScheme::colorEntry(int index, uint randomSeed) const
 
     QColor entry = colorTable()[index];
 
-    if (!_colorRandomization || randomSeed == 0 || _randomTable == nullptr
-            || _randomTable[index].isNull()) {
+    if (!_colorRandomization || randomSeed == 0 || _randomTable == nullptr || _randomTable[index].isNull()) {
         return entry;
     }
 
     double baseHue;
     double baseSaturation;
     double baseLightness;
-    rgb2hsluv(entry.redF(), entry.greenF(), entry.blueF(),
-              &baseHue, &baseSaturation, &baseLightness);
+    rgb2hsluv(entry.redF(), entry.greenF(), entry.blueF(), &baseHue, &baseSaturation, &baseLightness);
 
     const RandomizationRange &range = _randomTable[index];
 
@@ -290,15 +289,16 @@ QColor ColorScheme::colorEntry(int index, uint randomSeed) const
     if (qFuzzyCompare(minSaturation, maxSaturation)) {
         saturation = baseSaturation;
     } else {
-        std::piecewise_linear_distribution<> saturationDistribution({minSaturation, maxSaturation},
-                                                                    [](double v) { return v; });
+        std::piecewise_linear_distribution<> saturationDistribution({minSaturation, maxSaturation}, [](double v) {
+            return v;
+        });
         saturation = saturationDistribution(randomEngine);
     }
 
     // Lightness range has base value at its center. The base
     // value is clamped to prevent the range from shrinking.
     // L=0 [=|=        ]    L=50 [    =|=    ]    L=100 [        =|=]
-    baseLightness = qBound(range.lightness / 2.0, baseLightness , MaxLightness - range.lightness);
+    baseLightness = qBound(range.lightness / 2.0, baseLightness, MaxLightness - range.lightness);
     const double minLightness = qMax(baseLightness - range.lightness / 2.0, 0.0);
     const double maxLightness = qMin(baseLightness + range.lightness / 2.0, MaxLightness);
     // Use triangular distribution with peak at L=50.0.
@@ -307,7 +307,9 @@ QColor ColorScheme::colorEntry(int index, uint randomSeed) const
     if (qFuzzyCompare(minLightness, maxLightness)) {
         lightness = baseLightness;
     } else {
-        static const auto lightnessWeightsFunc = [](double v) { return 50.0 - qAbs(v - 50.0); };
+        static const auto lightnessWeightsFunc = [](double v) {
+            return 50.0 - qAbs(v - 50.0);
+        };
         std::piecewise_linear_distribution<> lightnessDistribution;
         if (minLightness < 50.0 && 50.0 < maxLightness) {
             lightnessDistribution = std::piecewise_linear_distribution<>({minLightness, 50.0, maxLightness}, lightnessWeightsFunc);
@@ -350,11 +352,14 @@ void ColorScheme::setColorRandomization(bool randomize)
         // Set default randomization settings
         if (!hasAnyRandomizationEntries) {
             static const int ColorIndexesForRandomization[] = {
-                    ColorFgIndex,           ColorBgIndex,
-                    ColorFgIntenseIndex,    ColorBgIntenseIndex,
-                    ColorFgFaintIndex,      ColorBgFaintIndex,
+                ColorFgIndex,
+                ColorBgIndex,
+                ColorFgIntenseIndex,
+                ColorBgIntenseIndex,
+                ColorFgFaintIndex,
+                ColorBgFaintIndex,
             };
-            for (int index: ColorIndexesForRandomization) {
+            for (int index : ColorIndexesForRandomization) {
                 setRandomizationRange(index, MaxHue, MaxSaturation, 0.0);
             }
         }
@@ -408,7 +413,7 @@ bool ColorScheme::hasDarkBackground() const
 void ColorScheme::setOpacity(qreal opacity)
 {
     if (opacity < 0.0 || opacity > 1.0) {
-        qCDebug(ColorSchemeDebug)<<"ColorScheme"<<name()<<"has an invalid opacity"<<opacity<<"using 1";
+        qCDebug(ColorSchemeDebug) << "ColorScheme" << name() << "has an invalid opacity" << opacity << "using 1";
         opacity = 1.0;
     }
     _opacity = opacity;
@@ -451,7 +456,7 @@ void ColorScheme::readColorEntry(const KConfig &config, int index)
     KConfigGroup configGroup = config.group(colorNameForIndex(index));
 
     if (!configGroup.hasKey("Color") && _table != nullptr) {
-        setColorTableEntry(index, _table[index%BASE_COLORS]);
+        setColorTableEntry(index, _table[index % BASE_COLORS]);
         return;
     }
 
@@ -464,18 +469,23 @@ void ColorScheme::readColorEntry(const KConfig &config, int index)
         const double value = configGroup.readEntry(key, min);
         if (min > value || value > max) {
             qCDebug(ColorSchemeDebug) << QStringLiteral(
-                    "Color scheme \"%1\": color index 2 has an invalid value: %3 = %4. "
-                    "Allowed value range: %5 - %6. Using %7.")
-                    .arg(name()).arg(index).arg(QLatin1String(key)).arg(value, 0, 'g', 1)
-                    .arg(min, 0, 'g', 1).arg(max, 0, 'g', 1).arg(min, 0, 'g', 1);
+                                             "Color scheme \"%1\": color index 2 has an invalid value: %3 = %4. "
+                                             "Allowed value range: %5 - %6. Using %7.")
+                                             .arg(name())
+                                             .arg(index)
+                                             .arg(QLatin1String(key))
+                                             .arg(value, 0, 'g', 1)
+                                             .arg(min, 0, 'g', 1)
+                                             .arg(max, 0, 'g', 1)
+                                             .arg(min, 0, 'g', 1);
             return min;
         }
         return value;
     };
 
-    double hue        = readAndCheckConfigEntry(RandomHueRangeKey,        0.0, MaxHue);
+    double hue = readAndCheckConfigEntry(RandomHueRangeKey, 0.0, MaxHue);
     double saturation = readAndCheckConfigEntry(RandomSaturationRangeKey, 0.0, MaxSaturation);
-    double lightness  = readAndCheckConfigEntry(RandomLightnessRangeKey,  0.0, MaxLightness);
+    double lightness = readAndCheckConfigEntry(RandomLightnessRangeKey, 0.0, MaxLightness);
 
     if (!qFuzzyIsNull(hue) || !qFuzzyIsNull(saturation) || !qFuzzyIsNull(lightness)) {
         setRandomizationRange(index, hue, saturation, lightness);
@@ -515,7 +525,7 @@ void ColorScheme::writeColorEntry(KConfig &config, int index) const
         // "MaxRandomValue",
         // "MaxRandomSaturation"
     };
-    for (const auto key: obsoleteKeys) {
+    for (const auto key : obsoleteKeys) {
         if (configGroup.hasKey(key)) {
             configGroup.deleteEntry(key);
         }
@@ -526,16 +536,15 @@ void ColorScheme::writeColorEntry(KConfig &config, int index) const
     const auto checkAndMaybeSaveValue = [&](const char *key, double value) {
         const bool valueIsNull = qFuzzyCompare(value, 0.0);
         const bool keyExists = configGroup.hasKey(key);
-        const bool keyExistsAndHasDifferentValue = !qFuzzyCompare(configGroup.readEntry(key, value),
-                                                                  value);
+        const bool keyExistsAndHasDifferentValue = !qFuzzyCompare(configGroup.readEntry(key, value), value);
         if ((!valueIsNull && !keyExists) || keyExistsAndHasDifferentValue) {
             configGroup.writeEntry(key, value);
         }
     };
 
-    checkAndMaybeSaveValue(RandomHueRangeKey,        random.hue);
+    checkAndMaybeSaveValue(RandomHueRangeKey, random.hue);
     checkAndMaybeSaveValue(RandomSaturationRangeKey, random.saturation);
-    checkAndMaybeSaveValue(RandomLightnessRangeKey,  random.lightness);
+    checkAndMaybeSaveValue(RandomLightnessRangeKey, random.lightness);
 }
 
 void ColorScheme::setWallpaper(const QString &path)
