@@ -8,26 +8,26 @@
 #include "ColorSchemeEditor.h"
 
 // Qt
-#include <QFontMetrics>
-#include <QFileInfo>
 #include <QCompleter>
-#include <QFileSystemModel>
-#include <QIcon>
 #include <QFileDialog>
+#include <QFileInfo>
+#include <QFileSystemModel>
+#include <QFontMetrics>
+#include <QIcon>
 #include <QImageReader>
 
 // KDE
-#include <QColorDialog>
-#include <KWindowSystem>
 #include <KLocalizedString>
+#include <KWindowSystem>
+#include <QColorDialog>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QVBoxLayout>
 
 // Konsole
-#include "ui_ColorSchemeEditor.h"
-#include "ColorScheme.h"
 #include "../characters/CharacterColor.h"
+#include "ColorScheme.h"
+#include "ui_ColorSchemeEditor.h"
 
 using namespace Konsole;
 
@@ -35,18 +35,18 @@ using namespace Konsole;
 // because intense and faint colors are in separate columns
 const int COLOR_TABLE_ROW_LENGTH = TABLE_COLORS / 3;
 
-const int NAME_COLUMN = 0;           // column 0 : color names
-const int COLOR_COLUMN = 1;          // column 1 : actual colors
-const int INTENSE_COLOR_COLUMN = 2;  // column 2 : intense colors
-const int FAINT_COLOR_COLUMN = 3;    // column 2 : faint colors
+const int NAME_COLUMN = 0; // column 0 : color names
+const int COLOR_COLUMN = 1; // column 1 : actual colors
+const int INTENSE_COLOR_COLUMN = 2; // column 2 : intense colors
+const int FAINT_COLOR_COLUMN = 3; // column 2 : faint colors
 
-ColorSchemeEditor::ColorSchemeEditor(QWidget *parent) :
-    QDialog(parent),
-    _isNewScheme(false),
-    _ui(nullptr),
-    _colors(nullptr)
+ColorSchemeEditor::ColorSchemeEditor(QWidget *parent)
+    : QDialog(parent)
+    , _isNewScheme(false)
+    , _ui(nullptr)
+    , _colors(nullptr)
 {
-    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel|QDialogButtonBox::Apply);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Apply);
     auto mainWidget = new QWidget(this);
     auto mainLayout = new QVBoxLayout;
     setLayout(mainLayout);
@@ -56,9 +56,7 @@ ColorSchemeEditor::ColorSchemeEditor(QWidget *parent) :
     connect(buttonBox, &QDialogButtonBox::accepted, this, &ColorSchemeEditor::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &ColorSchemeEditor::reject);
     mainLayout->addWidget(buttonBox);
-    connect(buttonBox->button(QDialogButtonBox::Apply),
-            &QPushButton::clicked, this,
-            &Konsole::ColorSchemeEditor::saveColorScheme);
+    connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, this, &Konsole::ColorSchemeEditor::saveColorScheme);
     connect(okButton, &QPushButton::clicked, this, &Konsole::ColorSchemeEditor::saveColorScheme);
 
     // ui
@@ -67,23 +65,19 @@ ColorSchemeEditor::ColorSchemeEditor(QWidget *parent) :
 
     // description edit
     _ui->descriptionEdit->setClearButtonEnabled(true);
-    connect(_ui->descriptionEdit, &QLineEdit::textChanged, this,
-            &Konsole::ColorSchemeEditor::setDescription);
+    connect(_ui->descriptionEdit, &QLineEdit::textChanged, this, &Konsole::ColorSchemeEditor::setDescription);
 
     // transparency slider
     QFontMetrics metrics(font());
     _ui->transparencyPercentLabel->setMinimumWidth(metrics.boundingRect(QStringLiteral("100%")).width());
 
-    connect(_ui->transparencySlider, &QSlider::valueChanged, this,
-            &Konsole::ColorSchemeEditor::setTransparencyPercentLabel);
+    connect(_ui->transparencySlider, &QSlider::valueChanged, this, &Konsole::ColorSchemeEditor::setTransparencyPercentLabel);
 
     // blur behind window
-    connect(_ui->blurCheckBox, &QCheckBox::toggled, this,
-            &Konsole::ColorSchemeEditor::setBlur);
+    connect(_ui->blurCheckBox, &QCheckBox::toggled, this, &Konsole::ColorSchemeEditor::setBlur);
 
     // randomized background
-    connect(_ui->randomizedBackgroundCheck, &QCheckBox::toggled, this,
-            &Konsole::ColorSchemeEditor::setRandomizedBackgroundColor);
+    connect(_ui->randomizedBackgroundCheck, &QCheckBox::toggled, this, &Konsole::ColorSchemeEditor::setRandomizedBackgroundColor);
 
     // wallpaper stuff
     auto dirModel = new QFileSystemModel(this);
@@ -96,38 +90,31 @@ ColorSchemeEditor::ColorSchemeEditor(QWidget *parent) :
     _ui->wallpaperPath->setClearButtonEnabled(true);
     _ui->wallpaperSelectButton->setIcon(QIcon::fromTheme(QStringLiteral("image-x-generic")));
 
-    connect(_ui->wallpaperSelectButton, &QToolButton::clicked, this,
-            &Konsole::ColorSchemeEditor::selectWallpaper);
-    connect(_ui->wallpaperPath, &QLineEdit::textChanged, this,
-            &Konsole::ColorSchemeEditor::wallpaperPathChanged);
+    connect(_ui->wallpaperSelectButton, &QToolButton::clicked, this, &Konsole::ColorSchemeEditor::selectWallpaper);
+    connect(_ui->wallpaperPath, &QLineEdit::textChanged, this, &Konsole::ColorSchemeEditor::wallpaperPathChanged);
 
     // color table
     _ui->colorTable->setColumnCount(4);
     _ui->colorTable->setRowCount(COLOR_TABLE_ROW_LENGTH);
 
     QStringList labels;
-    labels << i18nc("@label:listbox Column header text for color names", "Name")
-           << i18nc("@label:listbox Column header text for the actual colors", "Color")
+    labels << i18nc("@label:listbox Column header text for color names", "Name") << i18nc("@label:listbox Column header text for the actual colors", "Color")
            << i18nc("@label:listbox Column header text for the actual intense colors", "Intense color")
            << i18nc("@label:listbox Column header text for the actual faint colors", "Faint color");
     _ui->colorTable->setHorizontalHeaderLabels(labels);
 
     // Set resize mode for colorTable columns
-    _ui->colorTable->horizontalHeader()->setSectionResizeMode(NAME_COLUMN,
-                                                              QHeaderView::ResizeToContents);
+    _ui->colorTable->horizontalHeader()->setSectionResizeMode(NAME_COLUMN, QHeaderView::ResizeToContents);
     _ui->colorTable->horizontalHeader()->setSectionResizeMode(COLOR_COLUMN, QHeaderView::Stretch);
-    _ui->colorTable->horizontalHeader()->setSectionResizeMode(INTENSE_COLOR_COLUMN,
-                                                              QHeaderView::Stretch);
-    _ui->colorTable->horizontalHeader()->setSectionResizeMode(FAINT_COLOR_COLUMN,
-                                                              QHeaderView::Stretch);
+    _ui->colorTable->horizontalHeader()->setSectionResizeMode(INTENSE_COLOR_COLUMN, QHeaderView::Stretch);
+    _ui->colorTable->horizontalHeader()->setSectionResizeMode(FAINT_COLOR_COLUMN, QHeaderView::Stretch);
 
     QTableWidgetItem *item = new QTableWidgetItem(QStringLiteral("Test"));
     _ui->colorTable->setItem(0, 0, item);
 
     _ui->colorTable->verticalHeader()->hide();
 
-    connect(_ui->colorTable, &QTableWidget::itemClicked, this,
-            &Konsole::ColorSchemeEditor::editColorItem);
+    connect(_ui->colorTable, &QTableWidget::itemClicked, this, &Konsole::ColorSchemeEditor::editColorItem);
 
     // warning label when transparency is not available
     _ui->transparencyWarningWidget->setWordWrap(true);
@@ -153,8 +140,7 @@ ColorSchemeEditor::~ColorSchemeEditor()
 void ColorSchemeEditor::editColorItem(QTableWidgetItem *item)
 {
     // ignore if this is not a color column
-    if (item->column() != COLOR_COLUMN && item->column() != INTENSE_COLOR_COLUMN
-        && item->column() != FAINT_COLOR_COLUMN) {
+    if (item->column() != COLOR_COLUMN && item->column() != INTENSE_COLOR_COLUMN && item->column() != FAINT_COLOR_COLUMN) {
         return;
     }
 
@@ -171,7 +157,7 @@ void ColorSchemeEditor::editColorItem(QTableWidgetItem *item)
 
         // and the faint color rows are in the final third of the color table
         if (item->column() == FAINT_COLOR_COLUMN) {
-            colorSchemeRow += 2*COLOR_TABLE_ROW_LENGTH;
+            colorSchemeRow += 2 * COLOR_TABLE_ROW_LENGTH;
         }
 
         _colors->setColorTableEntry(colorSchemeRow, color);
@@ -191,11 +177,9 @@ void ColorSchemeEditor::selectWallpaper()
     fileFormats += QLatin1String(")");
 
     const QString fileName = QFileDialog::getOpenFileName(this,
-                                                          i18nc("@title:window",
-                                                                "Select wallpaper image file"),
+                                                          i18nc("@title:window", "Select wallpaper image file"),
                                                           _ui->wallpaperPath->text(),
-                                                          i18nc("@label:textbox Filter in file open dialog",
-                                                                "Supported Images") + fileFormats);
+                                                          i18nc("@label:textbox Filter in file open dialog", "Supported Images") + fileFormats);
 
     if (!fileName.isEmpty()) {
         _ui->wallpaperPath->setText(fileName);
@@ -296,12 +280,11 @@ void ColorSchemeEditor::setupColorTable(const ColorScheme *colors)
 
         auto colorItemIntense = new QTableWidgetItem();
         colorItemIntense->setBackground(table[COLOR_TABLE_ROW_LENGTH + row]);
-        colorItemIntense->setFlags(colorItem->flags()
-                                   & ~Qt::ItemIsEditable & ~Qt::ItemIsSelectable);
+        colorItemIntense->setFlags(colorItem->flags() & ~Qt::ItemIsEditable & ~Qt::ItemIsSelectable);
         colorItemIntense->setToolTip(i18nc("@info:tooltip", "Click to choose intense color"));
 
         auto colorItemFaint = new QTableWidgetItem();
-        colorItemFaint->setBackground(table[2*COLOR_TABLE_ROW_LENGTH + row]);
+        colorItemFaint->setBackground(table[2 * COLOR_TABLE_ROW_LENGTH + row]);
         colorItemFaint->setFlags(colorItem->flags() & ~Qt::ItemIsEditable & ~Qt::ItemIsSelectable);
         colorItemFaint->setToolTip(i18nc("@info:tooltip", "Click to choose Faint color"));
 
