@@ -8,13 +8,14 @@
 #ifndef TERMINAL_IMAGE_FILTER_CHAIN
 #define TERMINAL_IMAGE_FILTER_CHAIN
 
-#include <memory>
 #include <QString>
+#include <memory>
 
-#include "FilterChain.h"
 #include "../characters/Character.h"
+#include "FilterChain.h"
 
-namespace Konsole {
+namespace Konsole
+{
 class TerminalDisplay;
 
 /** A filter chain which processes character images from terminal displays */
@@ -32,14 +33,13 @@ public:
      * @param columns The number of columns in the terminal image
      * @param lineProperties The line properties to set for image
      */
-    void setImage(const Character * const image, int lines, int columns,
-                  const QVector<LineProperty> &lineProperties);
+    void setImage(const Character *const image, int lines, int columns, const QVector<LineProperty> &lineProperties);
 
 private:
     Q_DISABLE_COPY(TerminalImageFilterChain)
 
-/* usually QStrings and QLists are not supposed to be in the heap, here we have a problem:
-    we need a shared memory space between many filter objeccts, defined by this TerminalImage. */
+    /* usually QStrings and QLists are not supposed to be in the heap, here we have a problem:
+        we need a shared memory space between many filter objeccts, defined by this TerminalImage. */
     std::unique_ptr<QString> _buffer;
     std::unique_ptr<QList<int>> _linePositions;
 };
