@@ -14,27 +14,28 @@
 
 class SSHConfigurationData;
 
-class SSHManagerModel : public QStandardItemModel {
+class SSHManagerModel : public QStandardItemModel
+{
     Q_OBJECT
 public:
     enum Roles {
-        SSHRole = Qt::UserRole + 1
+        SSHRole = Qt::UserRole + 1,
     };
 
     SSHManagerModel(QObject *parent = nullptr);
-    ~SSHManagerModel();
+    ~SSHManagerModel() override;
 
-    QStandardItem *addTopLevelItem(const QString& toplevel);
+    QStandardItem *addTopLevelItem(const QString &toplevel);
     void addChildItem(const SSHConfigurationData &config, const QString &parentName);
-    void editChildItem(const SSHConfigurationData &config, const QModelIndex& idx);
-    void removeIndex(const QModelIndex& idx);
+    void editChildItem(const SSHConfigurationData &config, const QModelIndex &idx);
+    void removeIndex(const QModelIndex &idx);
     bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
     QStringList folders() const;
 
     Qt::ItemFlags flags(const QModelIndex &index) const override;
 
     void startImportFromSshConfig();
-    void importFromSshConfigFile(const QString& file);
+    void importFromSshConfigFile(const QString &file);
     void load();
     void save();
 };
