@@ -10,8 +10,8 @@
 #include "Profile.h"
 
 // Qt
-#include <QTextCodec>
 #include <QRegularExpression>
+#include <QTextCodec>
 
 // KDE
 #include <KLocalizedString>
@@ -31,106 +31,113 @@ using namespace Konsole;
 //
 // the other names are usually shorter versions for convenience
 // when parsing konsoleprofile commands
-static const char GENERAL_GROUP[]     = "General";
-static const char KEYBOARD_GROUP[]    = "Keyboard";
-static const char APPEARANCE_GROUP[]  = "Appearance";
-static const char SCROLLING_GROUP[]   = "Scrolling";
-static const char TERMINAL_GROUP[]    = "Terminal Features";
-static const char CURSOR_GROUP[]      = "Cursor Options";
+static const char GENERAL_GROUP[] = "General";
+static const char KEYBOARD_GROUP[] = "Keyboard";
+static const char APPEARANCE_GROUP[] = "Appearance";
+static const char SCROLLING_GROUP[] = "Scrolling";
+static const char TERMINAL_GROUP[] = "Terminal Features";
+static const char CURSOR_GROUP[] = "Cursor Options";
 static const char INTERACTION_GROUP[] = "Interaction Options";
-static const char ENCODING_GROUP[]    = "Encoding Options";
+static const char ENCODING_GROUP[] = "Encoding Options";
 
 const Profile::PropertyInfo Profile::DefaultPropertyNames[] = {
     // General
-    { Path , "Path" , nullptr , QVariant::String }
-    , { Name , "Name" , GENERAL_GROUP , QVariant::String }
-    , { UntranslatedName, "UntranslatedName" , nullptr , QVariant::String }
-    , { Icon , "Icon" , GENERAL_GROUP , QVariant::String }
-    , { Command , "Command" , nullptr , QVariant::String }
-    , { Arguments , "Arguments" , nullptr , QVariant::StringList }
-    , { MenuIndex, "MenuIndex" , nullptr, QVariant::String }
-    , { Environment , "Environment" , GENERAL_GROUP , QVariant::StringList }
-    , { Directory , "Directory" , GENERAL_GROUP , QVariant::String }
-    , { LocalTabTitleFormat , "LocalTabTitleFormat" , GENERAL_GROUP , QVariant::String }
-    , { LocalTabTitleFormat , "tabtitle" , nullptr , QVariant::String }
-    , { RemoteTabTitleFormat , "RemoteTabTitleFormat" , GENERAL_GROUP , QVariant::String }
-    , { ShowTerminalSizeHint , "ShowTerminalSizeHint" , GENERAL_GROUP , QVariant::Bool }
-    , { StartInCurrentSessionDir , "StartInCurrentSessionDir" , GENERAL_GROUP , QVariant::Bool }
-    , { SilenceSeconds, "SilenceSeconds" , GENERAL_GROUP , QVariant::Int }
-    , { TerminalColumns, "TerminalColumns" , GENERAL_GROUP , QVariant::Int }
-    , { TerminalRows, "TerminalRows" , GENERAL_GROUP , QVariant::Int }
-    , { TerminalMargin, "TerminalMargin" , GENERAL_GROUP , QVariant::Int }
-    , { TerminalCenter, "TerminalCenter" , GENERAL_GROUP , QVariant::Bool }
+    {Path, "Path", nullptr, QVariant::String},
+    {Name, "Name", GENERAL_GROUP, QVariant::String},
+    {UntranslatedName, "UntranslatedName", nullptr, QVariant::String},
+    {Icon, "Icon", GENERAL_GROUP, QVariant::String},
+    {Command, "Command", nullptr, QVariant::String},
+    {Arguments, "Arguments", nullptr, QVariant::StringList},
+    {MenuIndex, "MenuIndex", nullptr, QVariant::String},
+    {Environment, "Environment", GENERAL_GROUP, QVariant::StringList},
+    {Directory, "Directory", GENERAL_GROUP, QVariant::String},
+    {LocalTabTitleFormat, "LocalTabTitleFormat", GENERAL_GROUP, QVariant::String},
+    {LocalTabTitleFormat, "tabtitle", nullptr, QVariant::String},
+    {RemoteTabTitleFormat, "RemoteTabTitleFormat", GENERAL_GROUP, QVariant::String},
+    {ShowTerminalSizeHint, "ShowTerminalSizeHint", GENERAL_GROUP, QVariant::Bool},
+    {StartInCurrentSessionDir, "StartInCurrentSessionDir", GENERAL_GROUP, QVariant::Bool},
+    {SilenceSeconds, "SilenceSeconds", GENERAL_GROUP, QVariant::Int},
+    {TerminalColumns, "TerminalColumns", GENERAL_GROUP, QVariant::Int},
+    {TerminalRows, "TerminalRows", GENERAL_GROUP, QVariant::Int},
+    {TerminalMargin, "TerminalMargin", GENERAL_GROUP, QVariant::Int},
+    {TerminalCenter, "TerminalCenter", GENERAL_GROUP, QVariant::Bool}
 
     // Appearance
-    , { Font , "Font" , APPEARANCE_GROUP , QVariant::Font }
-    , { ColorScheme , "ColorScheme" , APPEARANCE_GROUP , QVariant::String }
-    , { ColorScheme , "colors" , nullptr , QVariant::String }
-    , { AntiAliasFonts, "AntiAliasFonts" , APPEARANCE_GROUP , QVariant::Bool }
-    , { BoldIntense, "BoldIntense", APPEARANCE_GROUP, QVariant::Bool }
-    , { UseFontLineCharacters, "UseFontLineChararacters", APPEARANCE_GROUP, QVariant::Bool }
-    , { LineSpacing , "LineSpacing" , APPEARANCE_GROUP , QVariant::Int }
-    , { TabColor, "TabColor", APPEARANCE_GROUP, QVariant::Color }
-    , { DimValue, "DimmValue", APPEARANCE_GROUP, QVariant::Int }
-    , { DimWhenInactive , "DimWhenInactive" , GENERAL_GROUP , QVariant::Bool }
-    , { InvertSelectionColors , "InvertSelectionColors" , GENERAL_GROUP , QVariant::Bool }
+    ,
+    {Font, "Font", APPEARANCE_GROUP, QVariant::Font},
+    {ColorScheme, "ColorScheme", APPEARANCE_GROUP, QVariant::String},
+    {ColorScheme, "colors", nullptr, QVariant::String},
+    {AntiAliasFonts, "AntiAliasFonts", APPEARANCE_GROUP, QVariant::Bool},
+    {BoldIntense, "BoldIntense", APPEARANCE_GROUP, QVariant::Bool},
+    {UseFontLineCharacters, "UseFontLineChararacters", APPEARANCE_GROUP, QVariant::Bool},
+    {LineSpacing, "LineSpacing", APPEARANCE_GROUP, QVariant::Int},
+    {TabColor, "TabColor", APPEARANCE_GROUP, QVariant::Color},
+    {DimValue, "DimmValue", APPEARANCE_GROUP, QVariant::Int},
+    {DimWhenInactive, "DimWhenInactive", GENERAL_GROUP, QVariant::Bool},
+    {InvertSelectionColors, "InvertSelectionColors", GENERAL_GROUP, QVariant::Bool}
 
     // Keyboard
-    , { KeyBindings , "KeyBindings" , KEYBOARD_GROUP , QVariant::String }
+    ,
+    {KeyBindings, "KeyBindings", KEYBOARD_GROUP, QVariant::String}
 
     // Scrolling
-    , { HistoryMode , "HistoryMode" , SCROLLING_GROUP , QVariant::Int }
-    , { HistorySize , "HistorySize" , SCROLLING_GROUP , QVariant::Int }
-    , { ScrollBarPosition , "ScrollBarPosition" , SCROLLING_GROUP , QVariant::Int }
-    , { ScrollFullPage , "ScrollFullPage" , SCROLLING_GROUP , QVariant::Bool }
-    , { HighlightScrolledLines , "HighlightScrolledLines" , SCROLLING_GROUP , QVariant::Bool }
-    , { ReflowLines , "ReflowLines" , SCROLLING_GROUP , QVariant::Bool }
+    ,
+    {HistoryMode, "HistoryMode", SCROLLING_GROUP, QVariant::Int},
+    {HistorySize, "HistorySize", SCROLLING_GROUP, QVariant::Int},
+    {ScrollBarPosition, "ScrollBarPosition", SCROLLING_GROUP, QVariant::Int},
+    {ScrollFullPage, "ScrollFullPage", SCROLLING_GROUP, QVariant::Bool},
+    {HighlightScrolledLines, "HighlightScrolledLines", SCROLLING_GROUP, QVariant::Bool},
+    {ReflowLines, "ReflowLines", SCROLLING_GROUP, QVariant::Bool}
 
     // Terminal Features
-    , { UrlHintsModifiers , "UrlHintsModifiers" , TERMINAL_GROUP , QVariant::Int }
-    , { ReverseUrlHints , "ReverseUrlHints" , TERMINAL_GROUP , QVariant::Bool }
-    , { BlinkingTextEnabled , "BlinkingTextEnabled" , TERMINAL_GROUP , QVariant::Bool }
-    , { FlowControlEnabled , "FlowControlEnabled" , TERMINAL_GROUP , QVariant::Bool }
-    , { BidiRenderingEnabled , "BidiRenderingEnabled" , TERMINAL_GROUP , QVariant::Bool }
-    , { BlinkingCursorEnabled , "BlinkingCursorEnabled" , TERMINAL_GROUP , QVariant::Bool }
-    , { BellMode , "BellMode" , TERMINAL_GROUP , QVariant::Int }
-    , { VerticalLine, "VerticalLine", TERMINAL_GROUP, QVariant::Bool }
-    , { VerticalLineAtChar, "VerticalLineAtChar", TERMINAL_GROUP, QVariant::Int }
-    , { PeekPrimaryKeySequence, "PeekPrimaryKeySequence", TERMINAL_GROUP, QVariant::String }
+    ,
+    {UrlHintsModifiers, "UrlHintsModifiers", TERMINAL_GROUP, QVariant::Int},
+    {ReverseUrlHints, "ReverseUrlHints", TERMINAL_GROUP, QVariant::Bool},
+    {BlinkingTextEnabled, "BlinkingTextEnabled", TERMINAL_GROUP, QVariant::Bool},
+    {FlowControlEnabled, "FlowControlEnabled", TERMINAL_GROUP, QVariant::Bool},
+    {BidiRenderingEnabled, "BidiRenderingEnabled", TERMINAL_GROUP, QVariant::Bool},
+    {BlinkingCursorEnabled, "BlinkingCursorEnabled", TERMINAL_GROUP, QVariant::Bool},
+    {BellMode, "BellMode", TERMINAL_GROUP, QVariant::Int},
+    {VerticalLine, "VerticalLine", TERMINAL_GROUP, QVariant::Bool},
+    {VerticalLineAtChar, "VerticalLineAtChar", TERMINAL_GROUP, QVariant::Int},
+    {PeekPrimaryKeySequence, "PeekPrimaryKeySequence", TERMINAL_GROUP, QVariant::String}
     // Cursor
-    , { UseCustomCursorColor , "UseCustomCursorColor" , CURSOR_GROUP , QVariant::Bool}
-    , { CursorShape , "CursorShape" , CURSOR_GROUP , QVariant::Int}
-    , { CustomCursorColor , "CustomCursorColor" , CURSOR_GROUP , QVariant::Color }
-    , { CustomCursorTextColor , "CustomCursorTextColor" , CURSOR_GROUP , QVariant::Color }
+    ,
+    {UseCustomCursorColor, "UseCustomCursorColor", CURSOR_GROUP, QVariant::Bool},
+    {CursorShape, "CursorShape", CURSOR_GROUP, QVariant::Int},
+    {CustomCursorColor, "CustomCursorColor", CURSOR_GROUP, QVariant::Color},
+    {CustomCursorTextColor, "CustomCursorTextColor", CURSOR_GROUP, QVariant::Color}
 
     // Interaction
-    , { WordCharacters , "WordCharacters" , INTERACTION_GROUP , QVariant::String }
-    , { TripleClickMode , "TripleClickMode" , INTERACTION_GROUP , QVariant::Int }
-    , { UnderlineLinksEnabled , "UnderlineLinksEnabled" , INTERACTION_GROUP , QVariant::Bool }
-    , { UnderlineFilesEnabled , "UnderlineFilesEnabled" , INTERACTION_GROUP , QVariant::Bool }
-    , { OpenLinksByDirectClickEnabled , "OpenLinksByDirectClickEnabled" , INTERACTION_GROUP , QVariant::Bool }
-    , { TextEditorCmd , "TextEditorCmd" , INTERACTION_GROUP , QVariant::Int }
-    , { TextEditorCmdCustom , "TextEditorCmdCustom" , INTERACTION_GROUP , QVariant::String }
-    , { CtrlRequiredForDrag, "CtrlRequiredForDrag" , INTERACTION_GROUP , QVariant::Bool }
-    , { DropUrlsAsText , "DropUrlsAsText" , INTERACTION_GROUP , QVariant::Bool }
-    , { AutoCopySelectedText , "AutoCopySelectedText" , INTERACTION_GROUP , QVariant::Bool }
-    , { CopyTextAsHTML , "CopyTextAsHTML" , INTERACTION_GROUP , QVariant::Bool }
-    , { TrimLeadingSpacesInSelectedText , "TrimLeadingSpacesInSelectedText" , INTERACTION_GROUP , QVariant::Bool }
-    , { TrimTrailingSpacesInSelectedText , "TrimTrailingSpacesInSelectedText" , INTERACTION_GROUP , QVariant::Bool }
-    , { PasteFromSelectionEnabled , "PasteFromSelectionEnabled" , INTERACTION_GROUP , QVariant::Bool }
-    , { PasteFromClipboardEnabled , "PasteFromClipboardEnabled" , INTERACTION_GROUP , QVariant::Bool }
-    , { MiddleClickPasteMode, "MiddleClickPasteMode" , INTERACTION_GROUP , QVariant::Int }
-    , { MouseWheelZoomEnabled, "MouseWheelZoomEnabled", INTERACTION_GROUP, QVariant::Bool }
-    , { AlternateScrolling, "AlternateScrolling", INTERACTION_GROUP, QVariant::Bool }
-    , { AllowEscapedLinks, "AllowEscapedLinks", INTERACTION_GROUP, QVariant::Bool }
-    , { EscapedLinksSchema, "EscapedLinksSchema", INTERACTION_GROUP, QVariant::String }
-    , { ColorFilterEnabled, "ColorFilterEnabled", INTERACTION_GROUP, QVariant::Bool }
+    ,
+    {WordCharacters, "WordCharacters", INTERACTION_GROUP, QVariant::String},
+    {TripleClickMode, "TripleClickMode", INTERACTION_GROUP, QVariant::Int},
+    {UnderlineLinksEnabled, "UnderlineLinksEnabled", INTERACTION_GROUP, QVariant::Bool},
+    {UnderlineFilesEnabled, "UnderlineFilesEnabled", INTERACTION_GROUP, QVariant::Bool},
+    {OpenLinksByDirectClickEnabled, "OpenLinksByDirectClickEnabled", INTERACTION_GROUP, QVariant::Bool},
+    {TextEditorCmd, "TextEditorCmd", INTERACTION_GROUP, QVariant::Int},
+    {TextEditorCmdCustom, "TextEditorCmdCustom", INTERACTION_GROUP, QVariant::String},
+    {CtrlRequiredForDrag, "CtrlRequiredForDrag", INTERACTION_GROUP, QVariant::Bool},
+    {DropUrlsAsText, "DropUrlsAsText", INTERACTION_GROUP, QVariant::Bool},
+    {AutoCopySelectedText, "AutoCopySelectedText", INTERACTION_GROUP, QVariant::Bool},
+    {CopyTextAsHTML, "CopyTextAsHTML", INTERACTION_GROUP, QVariant::Bool},
+    {TrimLeadingSpacesInSelectedText, "TrimLeadingSpacesInSelectedText", INTERACTION_GROUP, QVariant::Bool},
+    {TrimTrailingSpacesInSelectedText, "TrimTrailingSpacesInSelectedText", INTERACTION_GROUP, QVariant::Bool},
+    {PasteFromSelectionEnabled, "PasteFromSelectionEnabled", INTERACTION_GROUP, QVariant::Bool},
+    {PasteFromClipboardEnabled, "PasteFromClipboardEnabled", INTERACTION_GROUP, QVariant::Bool},
+    {MiddleClickPasteMode, "MiddleClickPasteMode", INTERACTION_GROUP, QVariant::Int},
+    {MouseWheelZoomEnabled, "MouseWheelZoomEnabled", INTERACTION_GROUP, QVariant::Bool},
+    {AlternateScrolling, "AlternateScrolling", INTERACTION_GROUP, QVariant::Bool},
+    {AllowEscapedLinks, "AllowEscapedLinks", INTERACTION_GROUP, QVariant::Bool},
+    {EscapedLinksSchema, "EscapedLinksSchema", INTERACTION_GROUP, QVariant::String},
+    {ColorFilterEnabled, "ColorFilterEnabled", INTERACTION_GROUP, QVariant::Bool}
 
     // Encoding
-    , { DefaultEncoding , "DefaultEncoding" , ENCODING_GROUP , QVariant::String }
+    ,
+    {DefaultEncoding, "DefaultEncoding", ENCODING_GROUP, QVariant::String}
 
-    , { static_cast<Profile::Property>(0) , nullptr , nullptr, QVariant::Invalid }
-};
+    ,
+    {static_cast<Profile::Property>(0), nullptr, nullptr, QVariant::Invalid}};
 
 QHash<QString, Profile::PropertyInfo> Profile::PropertyInfoByName;
 QHash<Profile::Property, Profile::PropertyInfo> Profile::PropertyInfoByProperty;
@@ -143,7 +150,7 @@ void Profile::fillTableWithDefaultNames()
         return;
     }
 
-    const PropertyInfo* iter = DefaultPropertyNames;
+    const PropertyInfo *iter = DefaultPropertyNames;
     while (iter->name != nullptr) {
         registerProperty(*iter);
         iter++;
@@ -181,7 +188,11 @@ void Profile::useFallback()
     setProperty(MouseWheelZoomEnabled, true);
     setProperty(AlternateScrolling, true);
 
+#ifdef Q_OS_MACOS
+    setProperty(KeyBindings, QStringLiteral("macos"));
+#else
     setProperty(KeyBindings, QStringLiteral("default"));
+#endif
     setProperty(ColorScheme, QStringLiteral("Breeze"));
     setProperty(Font, QFontDatabase::systemFont(QFontDatabase::FixedFont));
 
@@ -250,7 +261,7 @@ Profile::Profile(const Profile::Ptr &parent)
 
 void Profile::clone(Profile::Ptr profile, bool differentOnly)
 {
-    const PropertyInfo* properties = DefaultPropertyNames;
+    const PropertyInfo *properties = DefaultPropertyNames;
     while (properties->name != nullptr) {
         Property current = properties->property;
         QVariant otherValue = profile->property<QVariant>(current);
@@ -259,8 +270,7 @@ void Profile::clone(Profile::Ptr profile, bool differentOnly)
         case Path:
             break;
         default:
-            if (!differentOnly ||
-                    property<QVariant>(current) != otherValue) {
+            if (!differentOnly || property<QVariant>(current) != otherValue) {
                 setProperty(current, otherValue);
             }
         }
@@ -303,7 +313,7 @@ QHash<Profile::Property, QVariant> Profile::setProperties() const
     return _propertyValues;
 }
 
-void Profile::setProperty(Property p, const QVariant& value)
+void Profile::setProperty(Property p, const QVariant &value)
 {
     _propertyValues.insert(p, value);
 }
@@ -313,7 +323,7 @@ bool Profile::isPropertySet(Property p) const
     return _propertyValues.contains(p);
 }
 
-Profile::Property Profile::lookupByName(const QString& name)
+Profile::Property Profile::lookupByName(const QString &name)
 {
     // insert default names into table the first time this is called
     fillTableWithDefaultNames();
@@ -321,7 +331,7 @@ Profile::Property Profile::lookupByName(const QString& name)
     return PropertyInfoByName[name.toLower()].property;
 }
 
-void Profile::registerProperty(const PropertyInfo& info)
+void Profile::registerProperty(const PropertyInfo &info)
 {
     QString name = QLatin1String(info.name);
     PropertyInfoByName.insert(name.toLower(), info);
@@ -336,7 +346,7 @@ void Profile::registerProperty(const PropertyInfo& info)
 const QStringList Profile::propertiesInfoList() const
 {
     QStringList info;
-    const PropertyInfo* iter = DefaultPropertyNames;
+    const PropertyInfo *iter = DefaultPropertyNames;
     while (iter->name != nullptr) {
         info << QLatin1String(iter->name) + QStringLiteral(" : ") + QLatin1String(QVariant(iter->type).typeName());
         iter++;
@@ -347,8 +357,7 @@ const QStringList Profile::propertiesInfoList() const
 
 const Profile::GroupPtr Profile::asGroup() const
 {
-    const Profile::GroupPtr ptr(dynamic_cast<ProfileGroup *>(
-                                    const_cast<Profile *>(this)));
+    const Profile::GroupPtr ptr(dynamic_cast<ProfileGroup *>(const_cast<Profile *>(this)));
     return ptr;
 }
 
@@ -362,7 +371,7 @@ QString Profile::textEditorCmd() const
     auto current = property<int>(Profile::TextEditorCmd);
 
     QString editorCmd;
-    switch(current) {
+    switch (current) {
     case Enum::Kate:
         editorCmd = QStringLiteral("kate PATH:LINE:COLUMN");
         break;
