@@ -10,18 +10,24 @@
 #define PROFILEMANAGER_H
 
 // Qt
-#include <QKeySequence>
 #include <QHash>
+#include <QKeySequence>
 #include <QList>
 #include <QSet>
-#include <QStringList>
-#include <QVariant>
 #include <QStack>
+#include <QStringList>
+#include <QUrl>
+#include <QVariant>
+
+#include <KSharedConfig>
+
+#include <vector>
 
 // Konsole
 #include "Profile.h"
 
-namespace Konsole {
+namespace Konsole
+{
 /**
  * Manages profiles which specify various settings for terminal sessions
  * and their displays.
@@ -31,6 +37,8 @@ class KONSOLEPROFILE_EXPORT ProfileManager : public QObject
     Q_OBJECT
 
 public:
+    using Iterator = std::vector<Profile::Ptr>::const_iterator;
+
     /**
      * Constructs a new profile manager and loads information about the available
      * profiles.
@@ -51,7 +59,7 @@ public:
      * Returns a list of all available profiles
      *
      * Initially only the profile currently set as the default is loaded.
-    *
+     *
      * When this method is called, it calls loadAllProfiles() internally to
      * ensure all available profiles are loaded and usable.
      */
@@ -62,13 +70,6 @@ public:
      */
     QList<Profile::Ptr> loadedProfiles() const;
 
-    /**
-     * Loads all available profiles.  This involves reading each
-     * profile configuration file from disk and parsing it.
-     * Therefore it should only be done when necessary.
-     */
-    void loadAllProfiles();
-
     /**
      * Loads a profile from the specified path and registers
      * it with the ProfileManager.
@@ -132,8 +133,7 @@ public:
      * set this to false if you want to preview possible changes to a profile but do not
      * wish to make them permanent.
      */
-    void changeProfile(Profile::Ptr profile, QHash<Profile::Property, QVariant> propertyMap,
-                       bool persistent = true);
+    void changeProfile(Profile::Ptr profile, QHash<Profile::Property, QVariant> propertyMap, bool persistent = true);
 
     /**
      * Sets the @p profile as the default profile for creating new sessions
@@ -152,13 +152,6 @@ public:
      */
     Profile::Ptr fallbackProfile() const;
 
-    /**
-     * Sorts @p list of profiles alphabetically.
-     *
-     * @param list The profiles list to sort
-     */
-    void sortProfiles(QList<Profile::Ptr> &list);
-
     /**
      * Associates a shortcut with a particular profile.
      */
@@ -190,7 +183,7 @@ Q_SIGNALS:
     void shortcutChanged(const Profile::Ptr &profile, const QKeySequence &newShortcut);
 
 public Q_SLOTS:
-    /** Saves settings (shortcuts, default profile etc.) to disk. */
+    /** Saves settings (currently only profile shortcuts) to disk. */
     void saveSettings();
 
 protected Q_SLOTS:
@@ -200,6 +193,13 @@ private Q_SLOTS:
 private:
     Q_DISABLE_COPY(ProfileManager)
 
+    /**
+     * Loads all available profiles. This involves reading each
+     * profile configuration file from disk and parsing it.
+     * Therefore it should only be done when necessary.
+     */
+    void loadAllProfiles(const QString &defaultProfileFileName = {});
+
     // loads the mappings between shortcut key sequences and
     // profile paths
     void loadShortcuts();
@@ -218,24 +218,31 @@ private:
     // otherwise
     QString saveProfile(const Profile::Ptr &profile);
 
-    QSet<Profile::Ptr> _profiles;  // list of all loaded profiles
+    // Sorts _profiles by profile name
+    void sortProfiles();
+
+    // Uses std::find to find "profile" _profiles
+    Iterator findProfile(const Profile::Ptr &profile) const;
+
+    // A list of all loaded profiles, sorted by profile name
+    std::vector<Profile::Ptr> _profiles;
 
     Profile::Ptr _defaultProfile;
     Profile::Ptr _fallbackProfile;
 
-    bool _loadedAllProfiles; // set to true after loadAllProfiles has been called
-
     struct ShortcutData {
         Profile::Ptr profileKey;
-        QString profilePath;
+        QKeySequence keySeq;
     };
-    QMap<QKeySequence, ShortcutData> _shortcuts; // shortcut keys -> profile path
+    std::vector<ShortcutData> _shortcuts;
 
-    // finds out if it's a internal profile or an external one,
-    // fixing the path to point to the correct location for the profile.
-    QString normalizePath(const QString& path) const;
+    // Set to true when setShortcut() is called so that when the ProfileSettings
+    // dialog is accepted the profiles shorcut changes are saved
+    bool _profileShortcutsChanged = false;
+
+    KSharedConfigPtr m_config;
 };
 
 }
 
-#endif //PROFILEMANAGER_H
+#endif // PROFILEMANAGER_H
