@@ -21,7 +21,7 @@
 using namespace Konsole;
 
 // FIXME: A dup line from Profile.cpp - redo these
-static const char GENERAL_GROUP[]     = "General";
+static const char GENERAL_GROUP[] = "General";
 
 ProfileWriter::ProfileWriter() = default;
 ProfileWriter::~ProfileWriter() = default;
@@ -35,11 +35,9 @@ QString ProfileWriter::getPath(const Profile::Ptr &profile)
 
     return localDataLocation % QLatin1String("/") % profile->untranslatedName() % QLatin1String(".profile");
 }
-void ProfileWriter::writeProperties(KConfig& config,
-                                        const Profile::Ptr &profile,
-                                        const Profile::PropertyInfo* properties)
+void ProfileWriter::writeProperties(KConfig &config, const Profile::Ptr &profile, const Profile::PropertyInfo *properties)
 {
-    const char* groupName = nullptr;
+    const char *groupName = nullptr;
     KConfigGroup group;
 
     while (properties->name != nullptr) {
@@ -50,15 +48,14 @@ void ProfileWriter::writeProperties(KConfig& config,
             }
 
             if (profile->isPropertySet(properties->property)) {
-                group.writeEntry(QLatin1String(properties->name),
-                                 profile->property<QVariant>(properties->property));
+                group.writeEntry(QLatin1String(properties->name), profile->property<QVariant>(properties->property));
             }
         }
 
         properties++;
     }
 }
-bool ProfileWriter::writeProfile(const QString& path , const Profile::Ptr &profile)
+bool ProfileWriter::writeProfile(const QString &path, const Profile::Ptr &profile)
 {
     KConfig config(path, KConfig::NoGlobals);
 
@@ -74,11 +71,9 @@ bool ProfileWriter::writeProfile(const QString& path , const Profile::Ptr &profi
         general.writeEntry("Parent", profile->parent()->path());
     }
 
-    if (profile->isPropertySet(Profile::Command)
-            || profile->isPropertySet(Profile::Arguments)) {
-        general.writeEntry("Command",
-                           ShellCommand(profile->command(), profile->arguments()).fullCommand());
-     }
+    if (profile->isPropertySet(Profile::Command) || profile->isPropertySet(Profile::Arguments)) {
+        general.writeEntry("Command", ShellCommand(profile->command(), profile->arguments()).fullCommand());
+    }
 
     // Write remaining properties
     writeProperties(config, profile, Profile::DefaultPropertyNames);
