@@ -8,20 +8,20 @@
 #include "PartManualTest.h"
 
 // Qt
-#include <QKeyEvent>
-#include <qtestkeyboard.h>
-#include <QMenu>
 #include <QAction>
+#include <QKeyEvent>
+#include <QMenu>
 #include <QMenuBar>
+#include <qtestkeyboard.h>
 // System
-#include <termios.h>
 #include <sys/types.h>
+#include <termios.h>
 
 // KDE
-#include <KPluginLoader>
-#include <KPluginFactory>
-#include <KService>
 #include <KMainWindow>
+#include <KPluginFactory>
+#include <KPluginLoader>
+#include <KService>
 #include <qtest.h>
 
 // Konsole
@@ -45,16 +45,16 @@ void PartManualTest::testShortcutOverride()
     // Create a main window with a menu and a test
     // action with a shortcut set to Ctrl+S, which is also used by the terminal
     auto mainWindow = new KMainWindow();
-    QMenu* fileMenu = mainWindow->menuBar()->addMenu(QStringLiteral("File"));
-    QAction* testAction = fileMenu->addAction(QStringLiteral("Test"));
+    QMenu *fileMenu = mainWindow->menuBar()->addMenu(QStringLiteral("File"));
+    QAction *testAction = fileMenu->addAction(QStringLiteral("Test"));
     testAction->setShortcut(QKeySequence(Konsole::ACCEL | Qt::Key_S));
     connect(testAction, &QAction::triggered, this, &Konsole::PartManualTest::shortcutTriggered);
 
     // Create terminal part and embed in into the main window
-    KParts::Part* terminalPart = createPart();
+    KParts::Part *terminalPart = createPart();
     QVERIFY(terminalPart);
     mainWindow->setCentralWidget(terminalPart->widget());
-    TerminalInterface* terminal = qobject_cast<TerminalInterface*>(terminalPart);
+    TerminalInterface *terminal = qobject_cast<TerminalInterface *>(terminalPart);
     QVERIFY(terminal);
     terminal->sendInput(QStringLiteral("Press Ctrl+S twice.\n"));
     mainWindow->show();
@@ -63,10 +63,9 @@ void PartManualTest::testShortcutOverride()
     _shortcutTriggered = false;
     _override = false;
     _overrideCalled = false;
-    QVERIFY(connect(terminalPart, SIGNAL(overrideShortcut(QKeyEvent*,bool&)),
-                    this, SLOT(overrideShortcut(QKeyEvent*,bool&))));
+    QVERIFY(connect(terminalPart, SIGNAL(overrideShortcut(QKeyEvent *, bool &)), this, SLOT(overrideShortcut(QKeyEvent *, bool &))));
 
-    //QTest::keyClick(terminalPart->widget(),Qt::Key_S,Qt::ControlModifier);
+    // QTest::keyClick(terminalPart->widget(),Qt::Key_S,Qt::ControlModifier);
     _shortcutEventLoop = new QEventLoop();
     _shortcutEventLoop->exec();
 
@@ -79,7 +78,7 @@ void PartManualTest::testShortcutOverride()
     _overrideCalled = false;
     _shortcutTriggered = false;
 
-    //QTest::keyClick(terminalPart->widget(),Qt::Key_S,Qt::ControlModifier);
+    // QTest::keyClick(terminalPart->widget(),Qt::Key_S,Qt::ControlModifier);
     _shortcutEventLoop->exec();
 
     QVERIFY(_overrideCalled);
@@ -90,7 +89,7 @@ void PartManualTest::testShortcutOverride()
     delete terminalPart;
     delete mainWindow;
 }
-void PartManualTest::overrideShortcut(QKeyEvent* event, bool& override)
+void PartManualTest::overrideShortcut(QKeyEvent *event, bool &override)
 {
     QVERIFY(override);
     if (event->modifiers() == Qt::ControlModifier && event->key() == Qt::Key_S) {
@@ -104,17 +103,16 @@ void PartManualTest::shortcutTriggered()
     _shortcutTriggered = true;
 }
 
-KParts::Part* PartManualTest::createPart()
+KParts::Part *PartManualTest::createPart()
 {
     KService::Ptr service = KService::serviceByDesktopName(QStringLiteral("konsolepart"));
     Q_ASSERT(service);
-    KPluginFactory* factory = KPluginLoader(service->library()).factory();
+    KPluginFactory *factory = KPluginLoader(service->library()).factory();
     Q_ASSERT(factory);
 
-    auto* terminalPart = factory->create<KParts::Part>(this);
+    auto *terminalPart = factory->create<KParts::Part>(this);
 
     return terminalPart;
 }
 
 QTEST_MAIN(PartManualTest)
-
