@@ -9,43 +9,49 @@
 #include "KonsoleSettings.h"
 
 // Qt
+#include <QApplication>
 #include <QChildEvent>
 #include <QDragEnterEvent>
 #include <QMimeData>
-#include <QApplication>
 #include <QStack>
 
 // C++
 #include <memory>
 
 // Konsole
-#include "widgets/ViewContainer.h"
 #include "terminalDisplay/TerminalDisplay.h"
+#include "widgets/ViewContainer.h"
 
-using Konsole::ViewSplitter;
 using Konsole::TerminalDisplay;
+using Konsole::ViewSplitter;
 
 bool ViewSplitter::m_drawTopLevelHandler;
 Qt::Orientation ViewSplitter::m_topLevelHandlerDrawnOrientation;
 
-//TODO: Connect the TerminalDisplay destroyed signal here.
+// TODO: Connect the TerminalDisplay destroyed signal here.
 
-namespace {
-    int calculateHandleWidth(int settingsEnum) {
-        switch (settingsEnum) {
-            case Konsole::KonsoleSettings::SplitDragHandleLarge: return 10;
-            case Konsole::KonsoleSettings::SplitDragHandleMedium: return  5;
-            case Konsole::KonsoleSettings::SplitDragHandleSmall: return  1;
-            default: return  1;
-        }
+namespace
+{
+int calculateHandleWidth(int settingsEnum)
+{
+    switch (settingsEnum) {
+    case Konsole::KonsoleSettings::SplitDragHandleLarge:
+        return 10;
+    case Konsole::KonsoleSettings::SplitDragHandleMedium:
+        return 5;
+    case Konsole::KonsoleSettings::SplitDragHandleSmall:
+        return 1;
+    default:
+        return 1;
     }
 }
+}
 
-ViewSplitter::ViewSplitter(QWidget *parent) :
-    QSplitter(parent)
+ViewSplitter::ViewSplitter(QWidget *parent)
+    : QSplitter(parent)
 {
     setAcceptDrops(true);
-    connect(KonsoleSettings::self(), &KonsoleSettings::configChanged, this, [this]{
+    connect(KonsoleSettings::self(), &KonsoleSettings::configChanged, this, [this] {
         setHandleWidth(calculateHandleWidth(KonsoleSettings::self()->splitDragHandleSize()));
     });
 }
@@ -56,7 +62,7 @@ void ViewSplitter::adjustActiveTerminalDisplaySize(int percentage)
     auto focusedTerminalDisplay = activeTerminalDisplay();
     Q_ASSERT(focusedTerminalDisplay);
 
-    auto parentSplitter = qobject_cast<ViewSplitter*>(focusedTerminalDisplay->parent());
+    auto parentSplitter = qobject_cast<ViewSplitter *>(focusedTerminalDisplay->parent());
     const int containerIndex = parentSplitter->indexOf(activeTerminalDisplay());
     Q_ASSERT(containerIndex != -1);
 
@@ -66,7 +72,7 @@ void ViewSplitter::adjustActiveTerminalDisplaySize(int percentage)
     const auto newSize = static_cast<int>(oldSize * (1.0 + percentage / 100.0));
     const int perContainerDelta = (count() == 1) ? 0 : ((newSize - oldSize) / (count() - 1)) * (-1);
 
-    for (int& size : containerSizes) {
+    for (int &size : containerSizes) {
         size += perContainerDelta;
     }
     containerSizes[containerIndex] = newSize;
@@ -99,8 +105,7 @@ void ViewSplitter::updateSizes()
 void ViewSplitter::addTerminalDisplay(TerminalDisplay *terminalDisplay, Qt::Orientation containerOrientation, AddBehavior behavior)
 {
     ViewSplitter *splitter = activeSplitter();
-    const int currentIndex = splitter->activeTerminalDisplay() == nullptr ? splitter->count()
-                            : splitter->indexOf(splitter->activeTerminalDisplay());
+    const int currentIndex = splitter->activeTerminalDisplay() == nullptr ? splitter->count() : splitter->indexOf(splitter->activeTerminalDisplay());
 
     if (splitter->count() < 2) {
         splitter->insertWidget(behavior == AddBehavior::AddBefore ? currentIndex : currentIndex + 1, terminalDisplay);
@@ -108,6 +113,7 @@ void ViewSplitter::addTerminalDisplay(TerminalDisplay *terminalDisplay, Qt::Orie
     } else if (containerOrientation == splitter->orientation()) {
         splitter->insertWidget(currentIndex, terminalDisplay);
     } else {
+        QList<int> sizes = splitter->sizes();
         auto newSplitter = new ViewSplitter();
         TerminalDisplay *oldTerminalDisplay = splitter->activeTerminalDisplay();
         const int oldContainerIndex = splitter->indexOf(oldTerminalDisplay);
@@ -115,12 +121,12 @@ void ViewSplitter::addTerminalDisplay(TerminalDisplay *terminalDisplay, Qt::Orie
         newSplitter->addWidget(behavior == AddBehavior::AddBefore ? terminalDisplay : oldTerminalDisplay);
         newSplitter->addWidget(behavior == AddBehavior::AddBefore ? oldTerminalDisplay : terminalDisplay);
         newSplitter->setOrientation(containerOrientation);
-        newSplitter->updateSizes();
         newSplitter->show();
         splitter->insertWidget(oldContainerIndex, newSplitter);
         splitter->m_blockPropagatedDeletion = false;
+        splitter->setSizes(sizes);
+        newSplitter->updateSizes();
     }
-    splitter->updateSizes();
 }
 
 void ViewSplitter::childEvent(QChildEvent *event)
@@ -152,8 +158,8 @@ void ViewSplitter::childEvent(QChildEvent *event)
         }
     }
 
-    auto terminals = getToplevelSplitter()->findChildren<TerminalDisplay*>();
-    for(auto terminal : terminals) {
+    auto terminals = getToplevelSplitter()->findChildren<TerminalDisplay *>();
+    for (auto terminal : terminals) {
         terminal->headerBar()->applyVisibilitySettings();
     }
 }
@@ -161,7 +167,7 @@ void ViewSplitter::childEvent(QChildEvent *event)
 void ViewSplitter::handleFocusDirection(Qt::Orientation orientation, int direction)
 {
     auto terminalDisplay = activeTerminalDisplay();
-    auto parentSplitter = qobject_cast<ViewSplitter*>(terminalDisplay->parentWidget());
+    auto parentSplitter = qobject_cast<ViewSplitter *>(terminalDisplay->parentWidget());
     auto topSplitter = parentSplitter->getToplevelSplitter();
 
     // Find the theme's splitter width + extra space to find valid terminal
@@ -172,25 +178,25 @@ void ViewSplitter::handleFocusDirection(Qt::Orientation orientation, int directi
     const auto startMapped = parentSplitter->mapTo(topSplitter, start);
 
     const int newX = orientation != Qt::Horizontal ? startMapped.x() + handleWidth
-             : direction == 1 ? startMapped.x() + terminalDisplay->width() + handleWidth
-             : startMapped.x() - handleWidth;
+        : direction == 1                           ? startMapped.x() + terminalDisplay->width() + handleWidth
+                                                   : startMapped.x() - handleWidth;
 
     const int newY = orientation != Qt::Vertical ? startMapped.y() + handleWidth
-                    : direction == 1 ? startMapped.y() + terminalDisplay->height() + handleWidth
-                    : startMapped.y() - handleWidth;
+        : direction == 1                         ? startMapped.y() + terminalDisplay->height() + handleWidth
+                                                 : startMapped.y() - handleWidth;
 
     const auto newPoint = QPoint(newX, newY);
     auto child = topSplitter->childAt(newPoint);
 
     TerminalDisplay *focusTerminal = nullptr;
-    if (auto* terminal = qobject_cast<TerminalDisplay*>(child)) {
+    if (auto *terminal = qobject_cast<TerminalDisplay *>(child)) {
         focusTerminal = terminal;
-    } else if (qobject_cast<QSplitterHandle*>(child) != nullptr) {
-        auto targetSplitter = qobject_cast<QSplitter*>(child->parent());
-        focusTerminal = qobject_cast<TerminalDisplay*>(targetSplitter->widget(0));
-    } else if (qobject_cast<QWidget*>(child) != nullptr) {
-        while(child != nullptr && focusTerminal == nullptr) {
-            focusTerminal = qobject_cast<TerminalDisplay*>(child->parentWidget());
+    } else if (qobject_cast<QSplitterHandle *>(child) != nullptr) {
+        auto targetSplitter = qobject_cast<QSplitter *>(child->parent());
+        focusTerminal = qobject_cast<TerminalDisplay *>(targetSplitter->widget(0));
+    } else if (qobject_cast<QWidget *>(child) != nullptr) {
+        while (child != nullptr && focusTerminal == nullptr) {
+            focusTerminal = qobject_cast<TerminalDisplay *>(child->parentWidget());
             child = child->parentWidget();
         }
     }
@@ -222,16 +228,15 @@ void ViewSplitter::focusRight()
 TerminalDisplay *ViewSplitter::activeTerminalDisplay() const
 {
     auto focusedWidget = focusWidget();
-    auto focusedTerminalDisplay = qobject_cast<TerminalDisplay*>(focusedWidget);
+    auto focusedTerminalDisplay = qobject_cast<TerminalDisplay *>(focusedWidget);
 
     // TD's child can be focused - try to find parent.
     while (focusedTerminalDisplay == nullptr && focusedWidget != nullptr && focusedWidget != this) {
         focusedWidget = focusedWidget->parentWidget();
-        focusedTerminalDisplay = qobject_cast<TerminalDisplay*>(focusedWidget);
+        focusedTerminalDisplay = qobject_cast<TerminalDisplay *>(focusedWidget);
     }
 
-    return focusedTerminalDisplay != nullptr ? focusedTerminalDisplay
-                                             : findChild<TerminalDisplay*>();
+    return focusedTerminalDisplay != nullptr ? focusedTerminalDisplay : findChild<TerminalDisplay *>();
 }
 
 void ViewSplitter::toggleMaximizeCurrentTerminal()
@@ -240,26 +245,29 @@ void ViewSplitter::toggleMaximizeCurrentTerminal()
     handleMinimizeMaximize(m_terminalMaximized);
 }
 
-namespace {
-    void restoreAll(QList<TerminalDisplay*>&& terminalDisplays, QList<ViewSplitter*>&& splitters) {
-        for (auto splitter : splitters) {
-            splitter->setVisible(true);
-        }
-        for (auto terminalDisplay : terminalDisplays) {
-            terminalDisplay->setVisible(true);
-        }
+namespace
+{
+void restoreAll(QList<TerminalDisplay *> &&terminalDisplays, QList<ViewSplitter *> &&splitters)
+{
+    for (auto splitter : splitters) {
+        splitter->setVisible(true);
+    }
+    for (auto terminalDisplay : terminalDisplays) {
+        terminalDisplay->setVisible(true);
     }
 }
+}
 
-bool ViewSplitter::hideRecurse(TerminalDisplay *currentTerminalDisplay) {
+bool ViewSplitter::hideRecurse(TerminalDisplay *currentTerminalDisplay)
+{
     bool allHidden = true;
 
-    for(int i = 0, end = count(); i < end; i++) {
-        if (auto *maybeSplitter = qobject_cast<ViewSplitter*>(widget(i))) {
+    for (int i = 0, end = count(); i < end; i++) {
+        if (auto *maybeSplitter = qobject_cast<ViewSplitter *>(widget(i))) {
             allHidden = maybeSplitter->hideRecurse(currentTerminalDisplay) && allHidden;
             continue;
         }
-        if (auto maybeTerminalDisplay = qobject_cast<TerminalDisplay*>(widget(i))) {
+        if (auto maybeTerminalDisplay = qobject_cast<TerminalDisplay *>(widget(i))) {
             if (maybeTerminalDisplay == currentTerminalDisplay) {
                 allHidden = false;
             } else {
@@ -282,35 +290,35 @@ void ViewSplitter::handleMinimizeMaximize(bool maximize)
     if (maximize) {
         for (int i = 0, end = topLevelSplitter->count(); i < end; i++) {
             auto widgetAt = topLevelSplitter->widget(i);
-            if (auto *maybeSplitter = qobject_cast<ViewSplitter*>(widgetAt)) {
+            if (auto *maybeSplitter = qobject_cast<ViewSplitter *>(widgetAt)) {
                 maybeSplitter->hideRecurse(currentTerminalDisplay);
             }
-            if (auto maybeTerminalDisplay = qobject_cast<TerminalDisplay*>(widgetAt)) {
+            if (auto maybeTerminalDisplay = qobject_cast<TerminalDisplay *>(widgetAt)) {
                 if (maybeTerminalDisplay != currentTerminalDisplay) {
                     maybeTerminalDisplay->setVisible(false);
                 }
             }
         }
     } else {
-        restoreAll(topLevelSplitter->findChildren<TerminalDisplay*>(),
-                   topLevelSplitter->findChildren<ViewSplitter*>());
+        restoreAll(topLevelSplitter->findChildren<TerminalDisplay *>(), topLevelSplitter->findChildren<ViewSplitter *>());
     }
 }
 
 ViewSplitter *ViewSplitter::getToplevelSplitter()
 {
     ViewSplitter *current = this;
-    while(qobject_cast<ViewSplitter*>(current->parentWidget()) != nullptr) {
-        current = qobject_cast<ViewSplitter*>(current->parentWidget());
+    while (qobject_cast<ViewSplitter *>(current->parentWidget()) != nullptr) {
+        current = qobject_cast<ViewSplitter *>(current->parentWidget());
     }
     return current;
 }
 
-namespace {
-    TerminalDisplay *currentDragTarget = nullptr;
+namespace
+{
+TerminalDisplay *currentDragTarget = nullptr;
 }
 
-void Konsole::ViewSplitter::dragEnterEvent(QDragEnterEvent* ev)
+void Konsole::ViewSplitter::dragEnterEvent(QDragEnterEvent *ev)
 {
     const auto dragId = QStringLiteral("konsole/terminal_display");
     if (ev->mimeData()->hasFormat(dragId)) {
@@ -326,10 +334,10 @@ void Konsole::ViewSplitter::dragEnterEvent(QDragEnterEvent* ev)
     }
 }
 
-void Konsole::ViewSplitter::dragMoveEvent(QDragMoveEvent* ev)
+void Konsole::ViewSplitter::dragMoveEvent(QDragMoveEvent *ev)
 {
     auto currentWidget = childAt(ev->pos());
-    if (auto terminal = qobject_cast<TerminalDisplay*>(currentWidget)) {
+    if (auto terminal = qobject_cast<TerminalDisplay *>(currentWidget)) {
         if ((currentDragTarget != nullptr) && currentDragTarget != terminal) {
             currentDragTarget->hideDragTarget();
         }
@@ -342,7 +350,7 @@ void Konsole::ViewSplitter::dragMoveEvent(QDragMoveEvent* ev)
     }
 }
 
-void Konsole::ViewSplitter::dragLeaveEvent(QDragLeaveEvent* event)
+void Konsole::ViewSplitter::dragLeaveEvent(QDragLeaveEvent *event)
 {
     Q_UNUSED(event)
     if (currentDragTarget != nullptr) {
@@ -351,7 +359,7 @@ void Konsole::ViewSplitter::dragLeaveEvent(QDragLeaveEvent* event)
     }
 }
 
-void Konsole::ViewSplitter::dropEvent(QDropEvent* ev)
+void Konsole::ViewSplitter::dropEvent(QDropEvent *ev)
 {
     if (ev->mimeData()->hasFormat(QStringLiteral("konsole/terminal_display"))) {
         if (getToplevelSplitter()->terminalMaximized()) {
@@ -359,18 +367,16 @@ void Konsole::ViewSplitter::dropEvent(QDropEvent* ev)
         }
         if (currentDragTarget != nullptr) {
             currentDragTarget->hideDragTarget();
-            auto source = qobject_cast<TerminalDisplay*>(ev->source());
+            auto source = qobject_cast<TerminalDisplay *>(ev->source());
             source->setVisible(false);
             source->setParent(nullptr);
 
             currentDragTarget->setFocus(Qt::OtherFocusReason);
             const auto droppedEdge = currentDragTarget->droppedEdge();
 
-            AddBehavior behavior = droppedEdge == Qt::LeftEdge || droppedEdge == Qt::TopEdge
-                ? AddBehavior::AddBefore : AddBehavior::AddAfter;
+            AddBehavior behavior = droppedEdge == Qt::LeftEdge || droppedEdge == Qt::TopEdge ? AddBehavior::AddBefore : AddBehavior::AddAfter;
 
-            Qt::Orientation orientation = droppedEdge == Qt::LeftEdge || droppedEdge == Qt::RightEdge
-                ? Qt::Horizontal : Qt::Vertical;
+            Qt::Orientation orientation = droppedEdge == Qt::LeftEdge || droppedEdge == Qt::RightEdge ? Qt::Horizontal : Qt::Vertical;
 
             // topLevel is the splitter that's connected with the ViewManager
             // that in turn can call the SessionController.
@@ -388,9 +394,9 @@ void Konsole::ViewSplitter::showEvent(QShowEvent *)
     setFocusProxy(activeSplitter()->activeTerminalDisplay());
 }
 
-QPoint Konsole::ViewSplitter::mapToTopLevel(const QPoint& p)
+QPoint Konsole::ViewSplitter::mapToTopLevel(const QPoint &p)
 {
-    auto parentSplitter = qobject_cast<ViewSplitter*>(parent());
+    auto parentSplitter = qobject_cast<ViewSplitter *>(parent());
     if (parentSplitter) {
         auto next_pos = mapToParent(p);
         return parentSplitter->mapToTopLevel(next_pos);
@@ -398,61 +404,59 @@ QPoint Konsole::ViewSplitter::mapToTopLevel(const QPoint& p)
     return p;
 }
 
-QPoint Konsole::ViewSplitter::mapFromTopLevel(const QPoint& p)
+QPoint Konsole::ViewSplitter::mapFromTopLevel(const QPoint &p)
 {
-
-    auto parentSplitter = qobject_cast<ViewSplitter*>(parent());
+    auto parentSplitter = qobject_cast<ViewSplitter *>(parent());
     if (parentSplitter) {
         return mapFromParent(parentSplitter->mapFromTopLevel(p));
     }
     return p;
 }
 
-Konsole::ViewSplitterHandle::ViewSplitterHandle(Qt::Orientation orientation, QSplitter* parent)
+Konsole::ViewSplitterHandle::ViewSplitterHandle(Qt::Orientation orientation, QSplitter *parent)
     : QSplitterHandle(orientation, parent)
+    , mouseReleaseEventCounter(0)
 {
 }
 
-QSplitterHandle* ViewSplitter::createHandle()
+QSplitterHandle *ViewSplitter::createHandle()
 {
     return new ViewSplitterHandle(orientation(), this);
 }
 
-namespace {
-    QList<int> allSplitterSizes;
+namespace
+{
+QList<int> allSplitterSizes;
 
-    int search_closest(const QList<int>& sorted_array, int x) {
-        if (sorted_array.isEmpty()) {
-            return -1;
-        }
-
-        auto iter_geq = std::lower_bound(
-            sorted_array.begin(),
-            sorted_array.end(),
-            x
-        );
-
-        if (iter_geq == sorted_array.begin()) {
-            return sorted_array[0];
-        }
-
-        int a = *(iter_geq - 1);
-        int b = *(iter_geq);
-
-        if (abs(x - a) < abs(x - b)) {
-            return a;
-        }
-
-        return b;
+int search_closest(const QList<int> &sorted_array, int x)
+{
+    if (sorted_array.isEmpty()) {
+        return -1;
     }
+
+    auto iter_geq = std::lower_bound(sorted_array.begin(), sorted_array.end(), x);
+
+    if (iter_geq == sorted_array.begin()) {
+        return sorted_array[0];
+    }
+
+    int a = *(iter_geq - 1);
+    int b = *(iter_geq);
+
+    if (abs(x - a) < abs(x - b)) {
+        return a;
+    }
+
+    return b;
+}
 }
 
 void Konsole::ViewSplitterHandle::mousePressEvent(QMouseEvent *ev)
 {
-    auto parentSplitter = qobject_cast<ViewSplitter*>(parentWidget());
+    auto parentSplitter = qobject_cast<ViewSplitter *>(parentWidget());
     auto topLevelSplitter = parentSplitter->getToplevelSplitter();
 
-    QList<ViewSplitter*> splitters = topLevelSplitter->findChildren<ViewSplitter*>();
+    QList<ViewSplitter *> splitters = topLevelSplitter->findChildren<ViewSplitter *>();
     splitters.append(topLevelSplitter);
 
     for (auto splitter : splitters) {
@@ -463,16 +467,11 @@ void Konsole::ViewSplitterHandle::mousePressEvent(QMouseEvent *ev)
         int delta = 0;
         for (auto point : splitter->sizes()) {
             delta += point;
-            QPoint thisPoint = orientation() == Qt::Horizontal
-                ? QPoint(delta, 0)
-                : QPoint(0, delta);
-
+            QPoint thisPoint = orientation() == Qt::Horizontal ? QPoint(delta, 0) : QPoint(0, delta);
 
             QPoint splitterPos = splitter->mapToTopLevel(thisPoint);
 
-            const int ourPos = orientation() == Qt::Horizontal
-                ? splitterPos.x()
-                : splitterPos.y();
+            const int ourPos = orientation() == Qt::Horizontal ? splitterPos.x() : splitterPos.y();
 
             allSplitterSizes.push_back(ourPos);
         }
@@ -489,30 +488,59 @@ void Konsole::ViewSplitterHandle::mousePressEvent(QMouseEvent *ev)
     }
     std::sort(std::begin(allSplitterSizes), std::end(allSplitterSizes));
 
+    mouseReleaseEventCounter = 0;
+
     QSplitterHandle::mousePressEvent(ev);
 }
 
 void Konsole::ViewSplitterHandle::mouseReleaseEvent(QMouseEvent *ev)
 {
     allSplitterSizes.clear();
+    if (++mouseReleaseEventCounter > 1) {
+        mouseDoubleClickEvent(ev);
+    }
     QSplitterHandle::mouseReleaseEvent(ev);
 }
 
 void Konsole::ViewSplitterHandle::mouseMoveEvent(QMouseEvent *ev)
 {
-    ViewSplitter *parentSplitter = qobject_cast<ViewSplitter*>(parentWidget());
+    ViewSplitter *parentSplitter = qobject_cast<ViewSplitter *>(parentWidget());
 
     QPoint thisPoint = parentSplitter->mapToTopLevel(mapToParent(ev->pos()));
 
     const int thisValue = orientation() == Qt::Horizontal ? thisPoint.x() : thisPoint.y();
-    const int nearest = search_closest(allSplitterSizes, thisValue );
+    const int nearest = search_closest(allSplitterSizes, thisValue);
     const int threshould = qAbs(nearest - thisValue);
     if (threshould <= 20) {
-        auto *thisSplitter = qobject_cast<ViewSplitter*>(splitter());
+        auto *thisSplitter = qobject_cast<ViewSplitter *>(splitter());
         QPoint localPoint = thisSplitter->mapFromTopLevel(orientation() == Qt::Horizontal ? QPoint(nearest, 0) : QPoint(0, nearest));
         moveSplitter(orientation() == Qt::Horizontal ? localPoint.x() : localPoint.y());
         return;
     }
 
+    mouseReleaseEventCounter = 0;
+
     QSplitterHandle::mouseMoveEvent(ev);
 }
+
+void Konsole::ViewSplitterHandle::mouseDoubleClickEvent(QMouseEvent *ev)
+{
+    auto parentSplitter = qobject_cast<ViewSplitter*>(parentWidget());
+
+    if (parentSplitter->count() > 1) {
+        for (int i = 1; i < parentSplitter->count(); i++) {
+            if (parentSplitter->handle(i) != this) {
+                continue;
+            }
+            if (orientation() == Qt::Horizontal) {
+                moveSplitter(parentSplitter->widget(i - 1)->pos().x() + ((parentSplitter->widget(i)->pos().x() + parentSplitter->widget(i)->width() - (parentSplitter->widget(i - 1)->pos().x())) / 2));
+            } else {
+                moveSplitter(parentSplitter->widget(i - 1)->pos().y() + ((parentSplitter->widget(i)->pos().y() + parentSplitter->widget(i)->height() - (parentSplitter->widget(i - 1)->pos().y())) / 2));
+            }
+            break;
+        }
+    }
+
+    mouseReleaseEventCounter = 0;
+    QSplitterHandle::mouseDoubleClickEvent(ev);
+}
